package jhdz.difusion.data.avisos;

import android.content.Context;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ArrayAdapter;
import android.widget.TextView;

import com.android.volley.Request;
import com.android.volley.RequestQueue;
import com.android.volley.Response;
import com.android.volley.VolleyError;
import com.android.volley.toolbox.JsonObjectRequest;
import com.android.volley.toolbox.Volley;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.util.ArrayList;
import java.util.List;

import jhdz.cultural.R;
import jhdz.difusion.constantes.URL_API;


/**
 * Created by core on 06/03/18.
 */

public class AdaptadorAvisos extends ArrayAdapter {  // Atributos

    private RequestQueue requestQueue;
    JsonObjectRequest jsArrayRequest;
    private static final String TAG = "AdaptadorAvisos";
    List<DatosAvisos> items;

    public AdaptadorAvisos(Context context) {
        super(context,0);

        // Crear nueva cola de peticiones
        requestQueue= Volley.newRequestQueue(context);

        // Nueva petición JSONObject
        jsArrayRequest = new JsonObjectRequest(
                Request.Method.POST,
                URL_API.AVISOS,
                null,
                new Response.Listener<JSONObject>() {
                    @Override
                    public void onResponse(JSONObject response) {

                        items = parseJson(response);
                        notifyDataSetChanged();
                    }
                },
                new Response.ErrorListener() {
                    @Override
                    public void onErrorResponse(VolleyError error) {
                        Log.d(TAG, "Error Respuesta en JSON: " + error.getMessage());

                    }
                }
        );


        requestQueue.add(jsArrayRequest);
    }

    @Override
    public int getCount() {
        return items != null ? items.size() : 0;
    }

    @Override
    public View getView(int position, View convertView, ViewGroup parent) {

        LayoutInflater layoutInflater = LayoutInflater.from(parent.getContext());


        View listItemView;


        listItemView = null == convertView ? layoutInflater.inflate(
                R.layout.tarjeta_avisos,
                parent,
                false) : convertView;


        DatosAvisos item = items.get(position);

        // Obtener Views
        TextView textoTitulo = (TextView) listItemView.
                findViewById(R.id.titulo_aviso);
        TextView textoDescripcion = (TextView) listItemView.
                findViewById(R.id.descripcion_aviso);

        TextView fecha = (TextView) listItemView.
                findViewById(R.id.fecha_aviso);


        // Actualizar los Views
        textoTitulo.setText(item.getTitulo());
        textoDescripcion.setText(item.getDescripcion());
        fecha.setText(item.getFecha_inicio());



        return listItemView;
    }

    public List<DatosAvisos> parseJson(JSONObject jsonObject){
        // Variables locales
        List<DatosAvisos> posts = new ArrayList();
        JSONArray jsonArray= null;

        try {
            // Obtener el array del objeto
            jsonArray = jsonObject.getJSONArray("avisos");

            for(int i=0; i<jsonArray.length(); i++){

                try {
                    JSONObject objeto= jsonArray.getJSONObject(i);

                    DatosAvisos datos = new DatosAvisos(
                            objeto.getString("evento_nombre"),
                            objeto.getString("evento_fecha"),
                            objeto.getString("evento_aviso"));


                    posts.add(datos);

                } catch (JSONException e) {
                    Log.e(TAG, "Error de parsing: "+ e.getMessage());
                }
            }

        } catch (JSONException e) {
            e.printStackTrace();
        }


        return posts;
    }
}

