package jhdz.difusion.data.evento;

import android.app.ProgressDialog;
import android.content.Context;
import android.content.Intent;
import android.support.v7.widget.CardView;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ArrayAdapter;
import android.widget.ImageView;
import android.widget.TextView;

import com.android.volley.Request;
import com.android.volley.RequestQueue;
import com.android.volley.Response;
import com.android.volley.VolleyError;
import com.android.volley.toolbox.JsonObjectRequest;
import com.android.volley.toolbox.Volley;
import com.squareup.picasso.Picasso;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.util.ArrayList;
import java.util.List;

import jhdz.cultural.R;
import jhdz.difusion.constantes.URL_API;

/**
 * Created by core on 06/03/18.
 */

public class AdaptadorCategorias extends ArrayAdapter {  // Atributos

    private RequestQueue requestQueue;
    JsonObjectRequest jsArrayRequest;

    private ProgressDialog pDialog;

    private static final String TAG = "PostAdapter";
    List<DatosCategoria> items;

    public AdaptadorCategorias(Context context) {
        super(context,0);

        // Crear nueva cola de peticiones
        requestQueue= Volley.newRequestQueue(context);

        // Nueva petición JSONObject
        jsArrayRequest = new JsonObjectRequest(
                Request.Method.GET,
                URL_API.CATEGORIA,
                null,
                new Response.Listener<JSONObject>() {
                    @Override
                    public void onResponse(JSONObject response) {
                        items = parseJson(response);
                        notifyDataSetChanged();
                    }
                },
                new Response.ErrorListener() {
                    @Override
                    public void onErrorResponse(VolleyError error) {
                        Log.d(TAG, "Error Respuesta en JSON: " + error.getMessage());

                    }
                }
        );

        // Añadir petición a la cola
        requestQueue.add(jsArrayRequest);

    }

    @Override
    public int getCount() {
        return items != null ? items.size() : 0;
    }

    @Override
    public View getView(int position, View convertView, ViewGroup parent) {

        LayoutInflater layoutInflater = LayoutInflater.from(parent.getContext());

        // Referencia del view procesado
        View listItemView;

        //Comprobando si el View no existe
        listItemView = null == convertView ? layoutInflater.inflate(
                R.layout.tarjeta,
                parent,
                false) : convertView;


        // Obtener el item actual
        DatosCategoria item = items.get(position);


        // Obtener Views
        TextView textoTitulo = (TextView) listItemView.
                findViewById(R.id.texto_Titulo);
        TextView textoDescripcion = (TextView) listItemView.
                findViewById(R.id.texto_Descripcion);
        CardView cardView =(CardView)listItemView.findViewById(R.id.cardView_categoria);
        // Actualizar los Views
        textoTitulo.setText(item.getCategoria());

        textoDescripcion.setText(item.getDescripcion());

        final ImageView imagenPost = (ImageView) listItemView.
                findViewById(R.id.imagenPost);

        // Actualizar los Views
        textoTitulo.setText(item.getCategoria());
        textoDescripcion.setText(item.getDescripcion());

        // Petición para obtener la imagen
        Picasso.with(getContext())
                .load(URL_API.SOURCE+item.getImg())
                .centerCrop()
                .fit()
                .error(R.drawable.ic_evento)
                .into(imagenPost);

        final  String id_categoria =  item.getId_categoria();

        listItemView.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                Intent activity = new Intent(getContext(), Eventos.class);
                //Envio de id de categoría
                activity.putExtra("id_categoria", id_categoria);
                getContext().startActivity(activity);
            }
        });

        return listItemView;
    }

    public List<DatosCategoria> parseJson(JSONObject jsonObject){
        // Variables locales

        List<DatosCategoria> posts = new ArrayList();
        JSONArray jsonArray= null;

        try {
            // Obtener el array del objeto
            jsonArray = jsonObject.getJSONArray("categoria");

            for(int i=0; i<jsonArray.length(); i++){

                try {
                    JSONObject objeto= jsonArray.getJSONObject(i);

                    DatosCategoria datos = new DatosCategoria(
                            objeto.getString("categoria_nombre"),
                            objeto.getString("categoria_descripcion"),
                            objeto.getString("categoria_img"),
                            objeto.getString("categoria_id")
                    );


                    posts.add(datos);

                } catch (JSONException e) {
                    Log.e(TAG, "Error de parsing: "+ e.getMessage());
                }
            }

        } catch (JSONException e) {
            e.printStackTrace();
        }


        return posts;
    }

}
